@@ -1,6 +1,8 @@
 """SpuriousEmu interface"""
 
+from .code import Formatter
 from .compiler import Compiler, Unit, Program
+from .deobfuscation import Deobfuscator, ManglingClassifier
 from .error import *
 from .interpreter import Interpreter
 from .preprocessor import Preprocessor
@@ -9,4 +11,4 @@ from .serialize import Serializer
 from .syntax import Parser, AST
 from .side_effect import OutsideWorld
 
-__version__ = "0.3.1"
+__version__ = "0.4.1"
