@@ -3,7 +3,6 @@
 from abc import ABC, abstractmethod
 from typing import List, Optional, Dict, Any, Union
 
-from .operator import BinaryOperator
 from .type import Type
 from .visitor import Visitable
 
@@ -161,11 +160,14 @@ class FunDef(Block):
     arguments: "ArgListDef"
 
     def __init__(
-        self, name: "Identifier", arguments: "ArgListDef", **kwargs
+        self,
+        name: "Identifier",
+        arguments: Optional["ArgListDef"] = None,
+        **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.name = name
-        self.arguments = arguments
+        self.arguments = arguments if arguments is not None else ArgListDef([])
 
 
 class ProcDef(Block):
@@ -175,11 +177,14 @@ class ProcDef(Block):
     arguments: "ArgListDef"
 
     def __init__(
-        self, name: "Identifier", arguments: "ArgListDef", **kwargs
+        self,
+        name: "Identifier",
+        arguments: Optional["ArgListDef"] = None,
+        **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.name = name
-        self.arguments = arguments
+        self.arguments = arguments if arguments is not None else ArgListDef([])
 
 
 ###########################
